==> de-2.26.1.zip: de/public.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%d attachments'] = '%d Dateianlagen';
L10n::$locales['%d comments'] = '%d Kommentare';
L10n::$locales['%d trackbacks'] = '%d Trackbacks';
L10n::$locales['%s reactions'] = '';
L10n::$locales['Access to content'] = 'Zum Inhalt';
L10n::$locales['Add a comment'] = 'Kommentar hinzufügen';
L10n::$locales['Add ping'] = '';
L10n::$locales['Additionnal style directives'] = '';
L10n::$locales['All keywords'] = 'Alle Schlüsselwörter';
L10n::$locales['Archives'] = 'Archive';
L10n::$locales['Attachments'] = 'Dateianlagen';
L10n::$locales['Best of me'] = 'Das Wichtigste über mich';
L10n::$locales['Blog info'] = 'Blog Information';
L10n::$locales['Blog menu'] = 'Blog Menü';
L10n::$locales['By'] = 'Von';
L10n::$locales['By category'] = 'Nach Kategorien';
L10n::$locales['By date'] = 'Nach Datum';
L10n::$locales['By tag'] = 'Nach Tags';
L10n::$locales['Categories'] = 'Kategorien';
L10n::$locales['Comment'] = 'Kommentar';
L10n::$locales['Comments'] = 'Kommentare';
L10n::$locales['Comments can be formatted using a simple wiki syntax.'] = 'Kommentare können mit einfacher Wiki-Syntax formatiert werden.';
L10n::$locales['Comments feed'] = 'Feed für Kommentare';
L10n::$locales['Continue reading'] = 'Weiterlesen';
L10n::$locales['Document not found'] = 'Dokument nicht gefunden';
L10n::$locales['Email address'] = 'E-Mail-Adresse';
L10n::$locales['Email address is not valid'] = 'Die E-Mail-Adresse ist nicht gültig';
L10n::$locales['Entries feed'] = 'Feed für Einträge';
L10n::$locales['Explore archives'] = '';
L10n::$locales['Extra menu'] = 'Extra Menü';
L10n::$locales['From'] = 'Von';
L10n::$locales['FromDay'] = 'Von';
L10n::$locales['Go to homepage'] = '';
L10n::$locales['HTML code is displayed as text and web addresses are automatically converted.'] = 'HTML-Code wird als normaler Text angezeigt, Links und Email-Adressen werden automatisch umgewandelt.';
L10n::$locales['Home'] = 'Startseite';
L10n::$locales['In'] = 'In';
L10n::$locales['Languages'] = 'Sprachen';
L10n::$locales['Links'] = 'Links';
L10n::$locales['Name or nickname'] = 'Name oder Nickname';
L10n::$locales['Next entry:'] = 'neure Einträge';
L10n::$locales['On'] = 'Am';
L10n::$locales['Page top'] = 'Nach oben';
L10n::$locales['Pagination'] = '';
L10n::$locales['Password needed'] = 'Passwort erforderlich';
L10n::$locales['Password:'] = 'Passwort:';
L10n::$locales['Permalink'] = 'Permalink';
L10n::$locales['Powered by %s'] = 'Erstellt mit %s';
L10n::$locales['Preview'] = 'Vorschau';
L10n::$locales['Previous entry:'] = 'ältere Einträge';
L10n::$locales['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = '<abbr xml:lang="de" lang="de" title="Really Simple Syndication">RSS</abbr> ist eine kostenlose Inhaltsübersicht für den Blog. Man kann Inhalte (z.B. Einträge oder Kommentare) oder auch Auszüge von Inhalten mit Links und anderen Metadaten abonnieren. Diese kannst du dann in einem beliebigen <a href="http://de.wikipedia.org/wiki/Feedreader">Feedreader</a>. lesen.';
L10n::$locales['Read'] = 'Lesen';
L10n::$locales['Remember me on this blog'] = 'Speichere meine Angaben für diesen Blog';
L10n::$locales['Required field'] = 'Pflichtfeld';
L10n::$locales['Search'] = 'Suche';
L10n::$locales['Send'] = 'Senden';
L10n::$locales['Simply copy the following URL into your aggregator:'] = 'Kopiere einfach den folgenden URL in deinen Feedreader:';
L10n::$locales['Subcategories'] = 'Unterkategorien';
L10n::$locales['Subscribe'] = 'Abnonnieren';
L10n::$locales['Subscribe to'] = 'Abonnieren von';
L10n::$locales['Suggestions:'] = '';
L10n::$locales['The document you are looking for does not exist.'] = 'Das gesuchte Dokument existiert nicht.';
L10n::$locales['The list of recents posts is available'] = '';
L10n::$locales['They posted on the same topic'] = 'Folgende haben zum gleichen Thema veröffentlicht';
L10n::$locales['This blog\'s comments Atom feed'] = 'Die Kommentare dieses Blogs als Atom-Feed abonnieren';
L10n::$locales['This category\'s comments Atom feed'] = 'Die Kommentare dieser Kategorie als Atom-Feed abonnieren';
L10n::$locales['This category\'s entries Atom feed'] = 'Die Einträge dieser Kategorie als Atom-Feed abonnieren';
L10n::$locales['This post\'s comments Atom feed'] = 'Die Kommentare dieses Eintrags als Atom-Feed abonnieren';
L10n::$locales['This post\'s comments feed'] = 'Die Kommentare dieses Eintrags als Atom-Feed abonnieren';
L10n::$locales['To content'] = 'Zum Inhalt';
L10n::$locales['To menu'] = 'Zum Menü';
L10n::$locales['To search'] = 'Zur Suche';
L10n::$locales['Trackback URL'] = 'Trackback-URL';
L10n::$locales['URL you\'ve tried has typos, or the page has been deleted or moved.'] = '';
L10n::$locales['Use search form'] = '';
L10n::$locales['Website'] = 'Website';
L10n::$locales['What is an RSS feed?'] = 'Was ist ein RSS-Feed?';
L10n::$locales['You must give a password to access this area.'] = 'Für den Zutritt benötigst du ein Passwort.';
L10n::$locales['You must provide a comment'] = 'Du musst einen Kommentar eingeben';
L10n::$locales['You must provide a valid email address.'] = 'Du mußt eine gültige E-Mail-Adresse verwenden.';
L10n::$locales['You must provide an author name'] = 'Du musst einen Namen oder Nicknamen angeben';
L10n::$locales['Your comment'] = 'Dein Kommentar';
L10n::$locales['Your comment has been published.'] = 'Ihr Kommentar wurde veröffentlicht.';
L10n::$locales['Your comment has been submitted and will be reviewed for publication.'] = 'Dein Kommentar wurde gespeichert und wird nach Überprüfung veröffentlicht.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Deine Suche nach <em>%1$s</em> ergab <strong>%2$s</strong> Treffer.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Deine Suche nach <em>%1$s</em> ergab <strong>%2$s</strong> Treffer.';
L10n::$locales['Your search for <em>%1$s</em> returned no result.'] = 'Deine Suche nach <em>%1$s</em> ergab keinen Treffer.';
L10n::$locales['by'] = 'von';
L10n::$locales['here'] = '';
L10n::$locales['in'] = 'in';
L10n::$locales['next entries'] = 'neure Einträge';
L10n::$locales['no attachments'] = 'Keine Dateianlage';
L10n::$locales['no comments'] = 'keine Kommentare';
L10n::$locales['no reactions'] = '';
L10n::$locales['no trackbacks'] = 'Kein Trackback';
L10n::$locales['of'] = 'von';
L10n::$locales['on'] = 'am';
L10n::$locales['one attachment'] = 'Eine Dateianlage';
L10n::$locales['one comment'] = 'Ein Kommentar';
L10n::$locales['one reaction'] = '';
L10n::$locales['one trackback'] = 'Ein Trackback';
L10n::$locales['optional'] = 'optional';
L10n::$locales['page'] = 'Seite';
L10n::$locales['preview'] = 'Vorschau';
L10n::$locales['previous entries'] = 'ältere Einträge';
L10n::$locales['reactions'] = '';
L10n::$locales['send'] = 'senden';
L10n::$locales['toDay'] = 'bis';

==> de-2.27.3.zip: de/public.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%d attachments'] = '%d Dateianlagen';
L10n::$locales['%d comments'] = '%d Kommentare';
L10n::$locales['%d trackbacks'] = '%d Trackbacks';
L10n::$locales['%s reactions'] = '%s Reaktionen';
L10n::$locales['Access to content'] = 'Zugang zum Inhalt';
L10n::$locales['Add a comment'] = 'Kommentar hinzufügen';
L10n::$locales['Add ping'] = 'Ping hinzufügen';
L10n::$locales['Additionnal style directives'] = 'Zusätzliche Stilrichtlinien';
L10n::$locales['All keywords'] = 'Alle Schlüsselwörter';
L10n::$locales['Archives'] = 'Archive';
L10n::$locales['Attachments'] = 'Dateianlagen';
L10n::$locales['Best of me'] = 'Das Wichtigste über mich';
L10n::$locales['Blog info'] = 'Blog Information';
L10n::$locales['Blog menu'] = 'Blog Menü';
L10n::$locales['By'] = 'Von';
L10n::$locales['By category'] = 'Nach Kategorien';
L10n::$locales['By date'] = 'Nach Datum';
L10n::$locales['By tag'] = 'Nach Tags';
L10n::$locales['Categories'] = 'Kategorien';
L10n::$locales['Comment'] = 'Kommentar';
L10n::$locales['Comments'] = 'Kommentare';
L10n::$locales['Comments can be formatted using a simple wiki syntax.'] = 'Kommentare können mit einfacher Wiki-Syntax formatiert werden.';
L10n::$locales['Comments feed'] = 'Feed für Kommentare';
L10n::$locales['Continue reading'] = 'Weiterlesen';
L10n::$locales['Document not found'] = 'Dokument nicht gefunden';
L10n::$locales['Email address'] = 'E-Mail-Adresse';
L10n::$locales['Email address is not valid'] = 'Die E-Mail-Adresse ist nicht gültig';
L10n::$locales['Entries feed'] = 'Feed für Einträge';
L10n::$locales['Explore archives'] = 'Archive durchsuchen';
L10n::$locales['Extra menu'] = 'Extra Menü';
L10n::$locales['From'] = 'Von';
L10n::$locales['FromDay'] = 'Von';
L10n::$locales['Go to homepage'] = 'Zur Homepage gehen';
L10n::$locales['HTML code is displayed as text and web addresses are automatically converted.'] = 'HTML-Code wird als normaler Text angezeigt, Links und Email-Adressen werden automatisch umgewandelt.';
L10n::$locales['Home'] = 'Startseite';
L10n::$locales['In'] = 'Unter';
L10n::$locales['Languages'] = 'Sprachen';
L10n::$locales['Links'] = 'Links';
L10n::$locales['Name or nickname'] = 'Name oder Nickname';
L10n::$locales['Next entry:'] = 'Nächster Eintrag:';
L10n::$locales['On'] = 'Am';
L10n::$locales['Page top'] = 'Nach oben';
L10n::$locales['Pagination'] = 'Paginierung';
L10n::$locales['Password needed'] = 'Passwort erforderlich';
L10n::$locales['Password:'] = 'Passwort:';
L10n::$locales['Permalink'] = 'Permalink';
L10n::$locales['Powered by %s'] = 'Erstellt mit %s';
L10n::$locales['Preview'] = 'Vorschau';
L10n::$locales['Previous entry:'] = 'Vorheriger Eintrag:';
L10n::$locales['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = '<abbr xml:lang="de" lang="de" title="Really Simple Syndication">RSS</abbr> ist eine kostenlose Inhaltsübersicht für den Blog. Man kann Inhalte (z.B. Einträge oder Kommentare) oder auch Auszüge von Inhalten mit Links und anderen Metadaten abonnieren. Diese kannst du dann in einem beliebigen <a href="http://de.wikipedia.org/wiki/Feedreader">Feedreader</a>. lesen.';
L10n::$locales['Read'] = 'Lesen';
L10n::$locales['Remember me on this blog'] = 'Speichere meine Angaben für diesen Blog';
L10n::$locales['Required field'] = 'Pflichtfeld';
L10n::$locales['Search'] = 'Suche';
L10n::$locales['Send'] = 'Senden';
L10n::$locales['Simply copy the following URL into your aggregator:'] = 'Kopiere einfach den folgenden URL in deinen Feedreader:';
L10n::$locales['Subcategories'] = 'Unterkategorien';
L10n::$locales['Subscribe'] = 'Abnonnieren';
L10n::$locales['Subscribe to'] = 'Abonnieren von';
L10n::$locales['Suggestions:'] = 'Vorschläge:';
L10n::$locales['The document you are looking for does not exist.'] = 'Das gesuchte Dokument existiert nicht.';
L10n::$locales['The list of recents posts is available'] = 'Die Liste der letzten Beiträge ist verfügbar';
L10n::$locales['They posted on the same topic'] = 'Folgende haben zum gleichen Thema veröffentlicht';
L10n::$locales['This blog\'s comments Atom feed'] = 'Die Kommentare dieses Blogs als Atom-Feed abonnieren';
L10n::$locales['This category\'s comments Atom feed'] = 'Die Kommentare dieser Kategorie als Atom-Feed abonnieren';
L10n::$locales['This category\'s entries Atom feed'] = 'Die Einträge dieser Kategorie als Atom-Feed abonnieren';
L10n::$locales['This post\'s comments Atom feed'] = 'Die Kommentare dieses Eintrags als Atom-Feed abonnieren';
L10n::$locales['This post\'s comments feed'] = 'Die Kommentare dieses Eintrags als Atom-Feed abonnieren';
L10n::$locales['To content'] = 'Zum Inhalt';
L10n::$locales['To menu'] = 'Zum Menü';
L10n::$locales['To search'] = 'Zur Suche';
L10n::$locales['Trackback URL'] = 'Trackback-URL';
L10n::$locales['URL you\'ve tried has typos, or the page has been deleted or moved.'] = 'Die URL, die Sie versucht haben, enthält Tippfehler, oder die Seite wurde gelöscht oder verschoben.';
L10n::$locales['Use search form'] = 'Suchformular verwenden';
L10n::$locales['Website'] = 'Website';
L10n::$locales['What is an RSS feed?'] = 'Was ist ein RSS-Feed?';
L10n::$locales['You must give a password to access this area.'] = 'Für den Zutritt benötigst du ein Passwort.';
L10n::$locales['You must provide a comment'] = 'Du musst einen Kommentar eingeben';
L10n::$locales['You must provide a valid email address.'] = 'Du mußt eine gültige E-Mail-Adresse verwenden.';
L10n::$locales['You must provide an author name'] = 'Du musst einen Namen oder Nicknamen angeben';
L10n::$locales['Your comment'] = 'Dein Kommentar';
L10n::$locales['Your comment has been published.'] = 'Ihr Kommentar wurde veröffentlicht.';
L10n::$locales['Your comment has been submitted and will be reviewed for publication.'] = 'Dein Kommentar wurde gespeichert und wird nach Überprüfung veröffentlicht.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Deine Suche nach <em>%1$s</em> ergab <strong>%2$s</strong> Treffer.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Deine Suche nach <em>%1$s</em> ergab <strong>%2$s</strong> Treffer.';
L10n::$locales['Your search for <em>%1$s</em> returned no result.'] = 'Deine Suche nach <em>%1$s</em> ergab keinen Treffer.';
L10n::$locales['by'] = 'von';
L10n::$locales['here'] = 'hier';
L10n::$locales['in'] = 'in';
L10n::$locales['next entries'] = 'neure Einträge';
L10n::$locales['no attachments'] = 'Keine Dateianlage';
L10n::$locales['no comments'] = 'keine Kommentare';
L10n::$locales['no reactions'] = 'keine Reaktionen';
L10n::$locales['no trackbacks'] = 'Kein Trackback';
L10n::$locales['of'] = 'von';
L10n::$locales['on'] = 'am';
L10n::$locales['one attachment'] = 'Eine Dateianlage';
L10n::$locales['one comment'] = 'Ein Kommentar';
L10n::$locales['one reaction'] = 'eine Reaktion';
L10n::$locales['one trackback'] = 'Ein Trackback';
L10n::$locales['optional'] = 'optional';
L10n::$locales['page'] = 'Seite';
L10n::$locales['preview'] = 'Vorschau';
L10n::$locales['previous entries'] = 'ältere Einträge';
L10n::$locales['reactions'] = 'Reaktionen';
L10n::$locales['send'] = 'senden';
L10n::$locales['toDay'] = 'bis';
